=======
Credits
=======

Development Lead
----------------

* Alexandre Courtois Auberger, and Bayan Saparbayeva <saparbayevabt@gmail.com>

Contributors
------------

* Vish Patel

None yet. Why not be the first?
